def setupVarious(context):

    # Ordinarily, GenericSetup handlers check for the existence of XML files.
    # Here, we are not parsing an XML file, but we use this text file as a
    # flag to check that we actually meant for this import step to be run.
    # The file is found in profiles/default.

    if context.readDataFile('plonetheme.bootstrapModern_various.txt') is None:
        return

    # Add additional setup code here



from zope.interface import Interface
from zope import schema
from plonetheme.bootstrapModern import MessageFactory as _

class IMediaTypes(Interface):
    """
    Marks all Media types from Products.media*
    """
    